MARVEL_ENTITIES = {
    "LABEL_1": [
        "Iron Man", "Thor Odinson", "Black Widow", "Spider-Man",
        "Loki Laufeyson", "Wolverine", "Captain America", "Doctor Strange",
        "Scarlet Witch", "Hawkeye", "Star-Lord", "Gamora", "Ant-Man",
        "Deadpool", "Nick Fury", "Vision", "Black Panther", "Captain Marvel"
    ],
    "LABEL_5": [
        "Wakanda", "Asgard", "Knowhere", "New York City", "Sokovia",
        "Kamar-Taj", "Xandar", "The Quantum Realm", "Hell's Kitchen",
        "Latveria", "Savage Land", "Genosha", "Mount Wundagore"
    ],
    "LABEL_3": [
        "S.H.I.E.L.D.", "Hydra", "The Avengers", "X-Men",
        "Stark Industries", "The Eternals", "Fantastic Four",
        "The Illuminati", "The Sinister Six", "A.I.M.",
        "The Ravagers", "Weapon X", "Oscorp"
    ]
}

STARWARS_ENTITIES = {
    "LABEL_1": [
        "Luke Skywalker", "Darth Vader", "Obi-Wan Kenobi",
        "Yoda", "Han Solo", "Leia Organa", "Kylo Ren",
        "Rey Skywalker", "Padmé Amidala", "Anakin Skywalker",
        "Mace Windu", "Count Dooku", "Qui-Gon Jinn"
    ],
    "LABEL_5": [
        "Tatooine", "Hoth", "Dagobah", "Endor", "Naboo",
        "Coruscant", "Mustafar", "Kashyyyk", "Geonosis",
        "Kamino", "Jakku", "Scarif", "Ahch-To"
    ],
    "LABEL_3": [
        "The Jedi Order", "The Sith", "The Galactic Empire",
        "The Rebel Alliance", "The First Order", "The Resistance",
        "The Galactic Republic", "The Trade Federation",
        "Clone Army", "Separatists", "Mandalorians", "New Republic"
    ]
}

HAPPRYPOTTER_ENTITIES = {
    "LABEL_1": [
        "Harry Potter", "Hermione Granger", "Ron Weasley", "Draco Malfoy",
        "Ginny Weasley", "Albus Dumbledore", "Severus Snape", "Sirius Black",
        "Lord Voldemort", "Rubeus Hagrid", "Luna Lovegood", "Neville Longbottom"
    ],
    "LABEL_5": [
        "Hogwarts", "Hogsmeade", "Diagon Alley", "The Forbidden Forest",
        "Godric's Hollow", "The Burrow", "Little Whinging", "Azkaban",
        "Knockturn Alley", "Ministry of Magic", "Shell Cottage"
    ],
    "LABEL_3": [
        "Gryffindor", "Slytherin", "Ravenclaw", "Hufflepuff",
        "Dumbledore's Army", "The Order of the Phoenix",
        "Death Eaters", "Ministry of Magic", "Hogwarts Express",
        "Quidditch Teams", "Magical Congress", "The Daily Prophet"
    ]
}